==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/CloudCredentialListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CloudCredentialListFluentImpl<A extends CloudCredentialListFluent<A>> extends BaseFluent<A> implements CloudCredentialListFluent<A>{
  public CloudCredentialListFluentImpl() {
  }
  public CloudCredentialListFluentImpl(CloudCredentialList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private ArrayList<CloudCredentialBuilder> items = new ArrayList<CloudCredentialBuilder>();
  private String kind;
  private ListMeta metadata;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(Integer index,CloudCredential item) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(Integer index,CloudCredential item) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    CloudCredentialBuilder builder = new CloudCredentialBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<CloudCredential> items) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<CloudCredential> items) {
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<CloudCredentialBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<CloudCredentialBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      CloudCredentialBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CloudCredential> getItems() {
    return items != null ? build(items) : null;
  }
  public List<CloudCredential> buildItems() {
    return items != null ? build(items) : null;
  }
  public CloudCredential buildItem(Integer index) {
    return this.items.get(index).build();
  }
  public CloudCredential buildFirstItem() {
    return this.items.get(0).build();
  }
  public CloudCredential buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public CloudCredential buildMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    for (CloudCredentialBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    for (CloudCredentialBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<CloudCredential> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new ArrayList(); for (CloudCredential item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (CloudCredential item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public CloudCredentialListFluent.ItemsNested<A> addNewItem() {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl();
  }
  public CloudCredentialListFluent.ItemsNested<A> addNewItemLike(CloudCredential item) {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public CloudCredentialListFluent.ItemsNested<A> setNewItemLike(Integer index,CloudCredential item) {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl(index, item);
  }
  public CloudCredentialListFluent.ItemsNested<A> editItem(Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public CloudCredentialListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public CloudCredentialListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public CloudCredentialListFluent.ItemsNested<A> editMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CloudCredentialListFluentImpl that = (CloudCredentialListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends CloudCredentialFluentImpl<CloudCredentialListFluent.ItemsNested<N>> implements CloudCredentialListFluent.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(Integer index,CloudCredential item) {
      this.index = index;
      this.builder = new CloudCredentialBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new CloudCredentialBuilder(this);
    }
    CloudCredentialBuilder builder;
    Integer index;
    public N and() {
      return (N) CloudCredentialListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/CloudCredentialListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CloudCredentialListFluentImpl<A extends CloudCredentialListFluent<A>> extends BaseFluent<A> implements CloudCredentialListFluent<A>{
  public CloudCredentialListFluentImpl() {
  }
  public CloudCredentialListFluentImpl(CloudCredentialList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private ArrayList<CloudCredentialBuilder> items = new ArrayList<CloudCredentialBuilder>();
  private String kind;
  private ListMeta metadata;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,CloudCredential item) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    CloudCredentialBuilder builder = new CloudCredentialBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,CloudCredential item) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    CloudCredentialBuilder builder = new CloudCredentialBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<CloudCredential> items) {
    if (this.items == null) {this.items = new ArrayList<CloudCredentialBuilder>();}
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<CloudCredential> items) {
    for (CloudCredential item : items) {CloudCredentialBuilder builder = new CloudCredentialBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<CloudCredentialBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<CloudCredentialBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      CloudCredentialBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CloudCredential> getItems() {
    return items != null ? build(items) : null;
  }
  public List<CloudCredential> buildItems() {
    return items != null ? build(items) : null;
  }
  public CloudCredential buildItem(int index) {
    return this.items.get(index).build();
  }
  public CloudCredential buildFirstItem() {
    return this.items.get(0).build();
  }
  public CloudCredential buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public CloudCredential buildMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    for (CloudCredentialBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    for (CloudCredentialBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<CloudCredential> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (CloudCredential item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.openshift.api.model.operator.v1.CloudCredential... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (CloudCredential item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> addNewItem() {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl();
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> addNewItemLike(CloudCredential item) {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> setNewItemLike(int index,CloudCredential item) {
    return new CloudCredentialListFluentImpl.ItemsNestedImpl(index, item);
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public CloudCredentialListFluentImpl.ItemsNested<A> editMatchingItem(Predicate<CloudCredentialBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CloudCredentialListFluentImpl that = (CloudCredentialListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends CloudCredentialFluentImpl<CloudCredentialListFluentImpl.ItemsNested<N>> implements CloudCredentialListFluentImpl.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(int index,CloudCredential item) {
      this.index = index;
      this.builder = new CloudCredentialBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new CloudCredentialBuilder(this);
    }
    CloudCredentialBuilder builder;
    int index;
    public N and() {
      return (N) CloudCredentialListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
